Funding
=======

Landlab is funded by the US National Science Foundation. It has been supported
by the following grants:

* A Collaborative NSF SI2-SSE proposal to
  University of Colorado (Greg Tucker,
  `1147454 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1147454&HistoricalAwards=false>`_),
  and the University of Washington (Erkan Istanbulluoglu,
  `1148305 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1148305&HistoricalAwards=false>`_)
* A Collaborative NSF SI2-SSI proposal to
  University of Colorado (Greg Tucker and Dan Hobley,
  `1450409 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1450409&HistoricalAwards=false>`_),
  Tulane University (Nicole Gasparini,
  `1450338 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1450338&HistoricalAwards=false>`_),
  and the University of Washington (Erkan Istanbulluoglu,
  `1450412 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1450412&HistoricalAwards=false>`_).
* A NSF EAR Postdoctoral Fellowship to Katy Barnhart
  (`1725774 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=1725774&HistoricalAwards=false>`_).
* A Collaborative NSF Frameworks proposal to University of Colorado (Greg Tucker,
  `2104102 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=2104102&HistoricalAwards=false>`_).
* A Collaborative NSF Facility proposal to University of Colorado (Greg Tucker,
  `2148762 <https://www.nsf.gov/awardsearch/showAward?AWD_ID=2148762&HistoricalAwards=false>`_).
